@@ -1,19 +1,15 @@
-#[macro_use]
-extern crate error_chain;
-
 #[macro_use]
 extern crate lazy_static;
 
 extern crate parol_runtime;
 
-mod errors;
 mod oberon_0_grammar;
 mod oberon_0_grammar_trait;
 mod oberon_0_parser;
 
-use crate::errors::*;
 use crate::oberon_0_grammar::Oberon0Grammar;
 use crate::oberon_0_parser::parse;
+use anyhow::{anyhow, Context, Result};
 use log::debug;
 use parol::generate_tree_layout;
 use std::env;
@@ -24,9 +20,7 @@ use std::fs;
 // To run the example
 // cargo run --example oberon_0 -- .\examples\oberon_0\Sample.mod
 
-quick_main!(run);
-
-fn run() -> Result<()> {
+fn main() -> Result<()> {
     // $env:RUST_LOG="parol_runtime=debug,oberon_0=debug"
     env_logger::init();
     debug!("env logger started");
@@ -35,14 +29,15 @@ fn run() -> Result<()> {
     if args.len() == 2 {
         let file_name = args[1].clone();
         let input = fs::read_to_string(file_name.clone())
-            .chain_err(|| format!("Can't read file {}", file_name))?;
+            .with_context(|| format!("Can't read file {}", file_name))?;
         let mut oberon_0_grammar = Oberon0Grammar::new();
         let syntax_tree = parse(&input, file_name.to_owned(), &mut oberon_0_grammar)
-            .chain_err(|| format!("Failed parsing file {}", file_name))?;
+            .with_context(|| format!("Failed parsing file {}", file_name))?;
         println!("\n{} successfully parsed!", file_name);
         println!("{}", oberon_0_grammar);
-        generate_tree_layout(&syntax_tree, &file_name).chain_err(|| "Error generating tree layout")
+        generate_tree_layout(&syntax_tree, &file_name)
+            .with_context(|| "Error generating tree layout")
     } else {
-        Err("Please provide a file name as single parameter!".into())
+        Err(anyhow!("Please provide a file name as single parameter!"))
     }
 }
