@@ -1,7 +1,7 @@
 use crate::scanner_states_grammar_trait::ScannerStatesGrammarTrait;
+use anyhow::{anyhow, bail, Result};
 use id_tree::Tree;
 use log::trace;
-use parol_runtime::errors::*;
 use parol_runtime::parser::{ParseTreeStackEntry, ParseTreeType};
 use std::fmt::{Debug, Display, Error, Formatter};
 
@@ -105,12 +105,12 @@ impl ScannerStatesGrammarTrait for ScannerStatesGrammar {
                 "f" => s.push('\u{c}'), // Formfeed
                 "n" => s.push('\n'),    // Newline
                 "t" => s.push('\t'),    // Tab
-                _ => return Err("Unhandled escape sequence".into()),
+                _ => bail!("Unhandled escape sequence"),
             }
             self.push(ScannerStatesGrammarItem::String(s), context);
             Ok(())
         } else {
-            Err(format!("{}: Expected 'String' on TOS.", context).into())
+            Err(anyhow!("{}: Expected 'String' on TOS.", context))
         }
     }
 
@@ -130,7 +130,7 @@ impl ScannerStatesGrammarTrait for ScannerStatesGrammar {
             self.push(ScannerStatesGrammarItem::String(s), context);
             Ok(())
         } else {
-            Err(format!("{}: Expected 'String' on TOS.", context).into())
+            Err(anyhow!("{}: Expected 'String' on TOS.", context))
         }
     }
 
